@@ -1,7 +1,20 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, Partition, MountedVolume
+from netbox_storage.models import Filesystem, Drive, Partition, MountedVolume, LinuxDevice
+
+
+#
+# Device
+#
+class NestedDeviceSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:linuxdevice-detail"
+    )
+
+    class Meta:
+        model = LinuxDevice
+        fields = ["id", "url", "display", "device", "type"]
 
 
 #
