@@ -341,16 +341,16 @@ class PartitionTemplateForm(NetBoxModelForm):
         ]
 
     def save(self, *args, **kwargs):
-        print(f"{self.cleaned_data['drive']}")
+        print(f"ID OF drive: {self.cleaned_data['drive'].pk}")
         # drive = Drive.objects.create()
 
-        # linux_device = LinuxDevice.objects.create(device='/dev/sda1', type='efi')
-        # partition = Partition.objects.create(drive=drive, device=linux_device, size=self.cleaned_data['size'], type='vfat')
+        linux_device = LinuxDevice.objects.create(device='/dev/sda1', type='efi')
+        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device, size=self.cleaned_data['size'], type='vfat')
 
         # template_configuration = super().save(*args, **kwargs)
 
         # print(f"{self.cleaned_data['size']}")
-        return None
+        return partition
 
 
 class VolumeSimpleForm(NetBoxModelForm):
