@@ -33,7 +33,7 @@ class Drive(NetBoxModel):
         ordering = ["size"]
 
     def __str__(self):
-        return f"{self.identifier}-{self.size}MB-{self.cluster})"
+        return f"{self.identifier}-{self.size}MB-{self.cluster}"
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
