@@ -40,7 +40,8 @@ from netbox_storage.views import (
     MountedVolumeView,
     MountedVolumeDeleteView, LVMAddSimpleView, AddSimpleLinuxVolumeView,
 )
-from netbox_storage.views.template import LVMAddTemplateView, AddTemplateVolumeView, AddTemplateDriveView
+from netbox_storage.views.template import LVMAddTemplateView, AddTemplateVolumeView, AddTemplateDriveView, \
+    AddTemplatePartitionView
 
 app_name = "netbox_storage"
 
